# Time-dependent-SEIRD-Model

**A Time-Dependent SEIRD Model for Forecasting the COVID-19 Transmission Dynamics**  
Taarak Rapolu, Brahmani Nutakki, T. Sobha Rani, S. Durga Bhavani  
doi: https://doi.org/10.1101/2020.05.29.20113571
